;; launch midi file after compilation has finished
;; launching takes place in the default application for ".mid" files

(setq *launch-midi-file* :launch)

; accepted values
;  :launch - launch the .mid file with the default .mid application
;  :open   - open the Symbolic Composer/Output Folder
;  nil     - does nothing

; Windows' default .mid application is set in the Windows
; system preferences. Most MIDI applications allow the MIDI
; file to open when double-clicking the file. SCOM launch
; uses the same Windows API call, and lauching is handled
; solely by Windows.

; truncating lengths to zone length

; Zone's length values may exceed the total zone length.
; By default this is let to happen and allows to hear if
; the lengths are not properly adjusted by the composer.
; However, looped length values, non-standard lengths, and
; zone lengts, and very small lengths which result variating
; tick values may sometimes cause zone overrun.
; This is fixed by setting (setq *truncate-bars* t). This
; forces length material to be cut at zone length.

(setq *truncate-bars* nil)

; ratio length correction during class expansion

; pre-processes length ratios into whole note tick range
; this minimizes rounding errors in class system calculations
; which may cause zone overrun situations between sections

(setq *correct-len-ratios* t)

; go menu sorting

; function names, definitions

(setq *sort-go-menu-groups* t) ; nil = same order as file

; document window subtitles

(setq *sort-go-menu-titles* nil) ; nil = same order as file

; use short long menus on windows
; change requires restarting SCOM

(defparameter *scom-editor-short-titles* t)

;; the following set window background, font color and style
;; cleartype font gives best outlook
;; on Windows XP  set font smooting on selecting cleartype at control panels/display/appearance/effects

; interface button font

(defparameter *button-font-name* "lucida console") ; "trebuchet ms"8 "microsoft sans serif"9 "lucida sans unicode"9 "verdana" "arial" "times" "comic sans ms"
(defparameter *button-font-size* 8)
(defparameter *button-font-weight* :medium)
(defparameter *button-font-style* :roman)

(defparameter *lookup-entry-font-name* "Geneva")
(defparameter *lookup-entry-font-size* 9)
(defparameter *lookup-entry-font-weight* :medium)
(defparameter *lookup-entry-font-style* :roman)

; main editor window

(setq *editor-bcolor* :white)
(setq *editor-fcolor* :black)
(setq *editor-font-name* "lucida console") ; "courier new" "fixedsys" "lucida console"
(setq *editor-font-size* 9)
(setq *editor-font-style* :roman)
(setq *editor-font-weight* :medium)

; documents and functions windows

(setq *functions-bcolor* :grey87) ; :snow1
(setq *functions-fcolor* :black)
(setq *functions-font-name* "lucida console") ; "courier new" 9 "lucida console"
(setq *functions-font-size* 9)
(setq *functions-font-style* :roman)
(setq *functions-font-weight* :medium)

; clone editor window

(setq *clone-bcolor* :floralwhite) ;:snow2)
(setq *clone-fcolor* :black)

; listener window

(setq *output-pane-bcolor* :white)
(setq *output-pane-fcolor* :black)
(setq *output-pane-font-name* "lucida console")
(setq *output-pane-font-size* 9)
(setq *output-pane-font-style* :roman)
(setq *output-pane-font-weight* :medium)

; index search window

(defparameter *find-index-bcolor* :white)
(defparameter *find-index-fcolor* :black)
(defparameter *find-index-font-name* *functions-font-name*) 
(defparameter *find-index-font-size* *functions-font-size*)
(defparameter *find-index-font-style* *functions-font-style*)
(defparameter *find-index-font-weight* *functions-font-weight*)

; system index

(setq *system-index-bcolor* :floralwhite)
(setq *system-index-fcolor* :black)
(setq *system-index-font-name* "microsoft sans serif") ; "trebuchet ms"8 "microsoft sans serif"9 "lucida sans unicode"9 "verdana" "arial" "times" "comic sans ms"
(setq *system-index-font-size* 9)
(setq *system-index-font-style* :roman)
(setq *system-index-font-weight* :medium)

; system index menu

(setq *system-index-menu-bcolor* :black)
(setq *system-index-menu-fcolor* :white)
(setq *system-index-menu-font-name* "microsoft sans serif") ; "verdana" "comic sans ms" "microsoft sans serif"
(setq *system-index-menu-font-size* 10)
(setq *system-index-menu-font-weight* :medium)
(setq *system-index-menu-font-style* :roman)

; note: use "courier new", proportionals do not work with editor
;       use windows font smoothing to increase 8 point readability
;           - specially if style :italic is used

;;; scope colors and density colors
;
; this one sets up the colors used to draw scope items
; this list is interpreted as
; 1 simultaneous items = :green
; 2,3,4 simultaneous items = :red
; 5,6,7 simultaneous items = :magenta
; etc
; last = if there are more simulataneus items last one is used
; you can define the coloring scheme to highlight certain
; density categories this way.

; green on black, with density coloring

(setq *scope-background-color* :black)
(setq *scope-font-color* :cyan)
(setq *scope-font-name* "microsoft sans serif")
(setq *scope-font-size* 9)
(setq *scope-font-style* :roman)
(setq *scope-font-weight* :medium)
(setq *scope-colors* '(:green :red :orange :orange :magenta :magenta :magenta :yellow :yellow :yellow :white :white :white :cyan))

; here is more specific, each level has its own color
;
;(setq *scope-colors* '(:slateblue2 :aliceblue :green :orangered1 :orangered1 :orangered1 :red :magenta :orange :gold :yellow :gray :lightgray :snow2 :white :lightblue :cyan :green :red :magenta :orange :gold :yellow :gray :lightgray :snow2 :white))

; black on white, no density coloring - uncomment if you prefer plain

;(setq *scope-background-color* :white)
;(setq *scope-font-color* :black)
;(setq *scope-font-name* "courier new")
;(setq *scope-font-size* 8)
;(setq *scope-font-style* :roman)
;(setq *scope-font-weight* :medium)
;
;(setq *scope-colors* '(:black))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; available colornames by the system

;(:azure :lavenderblush2 :grey86 :rosybrown1 :grey10 :aliceblue :gray87 :rosybrown2 :lavenderblush3 :gray11 :lavender :grey87 :rosybrown3 :grey11 :lavenderblush4 :lavenderblush :gray88 :gray12 :rosybrown4 :mistyrose1 :mistyrose :grey88 :grey12 :indianred1 :mistyrose2 :darkslategray :gray89 :gray13 :indianred2 :mistyrose3 :grey89 :darkslategrey :grey13 :indianred3 :mistyrose4 :gray90 :gray14 :indianred4 :dimgray :azure1 :grey90 :grey14 :sienna1 :dimgrey :azure2 :gray91 :gray15 :sienna2 :slategray :azure3 :grey91 :grey15 :sienna3 :slategrey :azure4 :gray92 :gray16 :sienna4 :lightslategray :slateblue1 :grey92 :grey16 :burlywood1 :slateblue2 :lightslategrey :gray93 :gray17 :burlywood2 :slateblue3 :lightgray :grey93 :grey17 :burlywood3 :slateblue4 :midnightblue :gray94 :gray18 :burlywood4 :royalblue1 :navy :grey94 :grey18 :wheat1 :royalblue2 :navyblue :gray95 win32:color_scrollbar :gray19 :wheat2 :royalblue3 :cornflowerblue :grey95 :grey19 :wheat3 win32:color_background :royalblue4 :gray96 :darkslateblue :gray20 :wheat4 :blue1 win32:color_activecaption :grey96 :grey20 :tan1 :slateblue :blue2 win32:color_inactivecaption :gray97 :gray21 :tan2 :mediumslateblue :blue3 :grey97 win32:color_menu :grey21 :tan3 :blue4 :lightslateblue :gray98 :gray22 :tan4 win32:color_window :dodgerblue1 :mediumblue :grey98 :grey22 :chocolate1 win32:color_windowframe :dodgerblue2 :royalblue :gray99 :gray23 :chocolate2 :dodgerblue3 win32:color_menutext :dodgerblue :grey99 :grey23 :chocolate3 :dodgerblue4 :deepskyblue win32:color_windowtext :gray100 :gray24 :chocolate4 :steelblue1 :skyblue :grey100 win32:color_captiontext :grey24 :firebrick1 :steelblue2 :lightskyblue win32:color_activeborder :gray25 :firebrick2 :steelblue3 :steelblue :grey25 :firebrick3 win32:color_inactiveborder :steelblue4 :lightsteelblue :gray26 :firebrick4 :deepskyblue1 win32:color_appworkspace :lightblue :grey26 :brown1 :deepskyblue2 win32:color_highlight :powderblue :gray27 :brown2 :deepskyblue3 win32:color_highlighttext :paleturquoise :grey27 :brown3 :gray28 :brown4 :deepskyblue4 win32:color_btnface :darkturquoise :grey28 :salmon1 :skyblue1 win32:color_btnshadow :mediumturquoise :gray29 :salmon2 :skyblue2 win32:color_graytext :turquoise :grey29 :salmon3 :skyblue3 :lightcyan win32:color_btntext :gray30 :salmon4 :skyblue4 :cadetblue win32:color_inactivecaptiontext :grey30 :lightsalmon1 :lightskyblue1 :mediumaquamarine :gray :gray31 :lightsalmon2 win32:color_btnhighlight :lightskyblue2 :aquamarine :grey31 :lightsalmon3 win32:color_3ddkshadow :lightskyblue3 :darkgreen :gray32 :lightsalmon4 win32:color_3dlight :lightskyblue4 :darkolivegreen :grey32 :orange1 win32:color_infotext :gray33 :slategray1 :darkseagreen :orange2 :grey33 :slategray2 win32:color_infobk :seagreen :orange3 :gray34 :slategray3 :mediumseagreen win32:color_desktop :orange4 :grey34 :slategray4 :lightseagreen win32:color_3dface :darkorange1 :gray35 :lightsteelblue1 :palegreen win32:color_3dshadow :darkorange2 :grey35 :lightsteelblue2 :springgreen :darkorange3 win32:color_3dhighlight :gray36 :lightsteelblue3 :lawngreen :darkorange4 :grey36 win32:color_3dhilight :lightsteelblue4 :chartreuse :coral1 :gray37 :mediumspringgreen :coral2 :lightblue1 :grey37 :coral3 :lightblue2 :greenyellow :gray38 :coral4 :lightblue3 :limegreen :grey38 :tomato1 :black :lightblue4 :yellowgreen :gray39 :tomato2 :lightcyan1 :forestgreen :grey39 :tomato3 :lightcyan2 :olivedrab :gray40 :tomato4 :lightcyan3 :darkkhaki :grey40 :orangered1 :lightcyan4 :khaki win32:color_btnhilight :gray41 :orangered2 :paleturquoise1 :palegoldenrod :grey41 :orangered3 :gray42 :paleturquoise2 :lightgoldenrodyellow :orangered4 :grey42 :paleturquoise3 :gold :red1 :gray43 :paleturquoise4 :lightgoldenrod :red2 :grey43 :cadetblue1 :goldenrod :red3 :gray44 :cadetblue2 :darkgoldenrod :red4 :grey44 :cadetblue3 :deeppink1 :rosybrown :gray45 :cadetblue4 :deeppink2 :indianred :grey45 :turquoise1 :deeppink3 :saddlebrown :gray46 :turquoise2 :deeppink4 :sienna :grey46 :turquoise3 :hotpink1 :peru :gray47 :turquoise4 :hotpink2 :burlywood :grey47 :cyan1 :hotpink3 :beige :gray48 :cyan2 :hotpink4 :wheat :grey48 :cyan3 :pink1 :sandybrown :gray49 :red :cyan4 :pink2 :tan :grey49 :pink :darkslategray1 :chocolate :pink3 :gray50 :firebrick :pink4 :darkslategray2 :grey50 :brown :lightpink1 :gray51 :darkslategray3 :darksalmon :lightpink2 :grey51 :darkslategray4 :salmon :lightpink3 :gray52 :aquamarine1 :lightsalmon :lightpink4 :grey52 :aquamarine2 :orange :palevioletred1 :gray53 :aquamarine3 :darkorange :grey53 :palevioletred2 :aquamarine4 :coral :gray54 :palevioletred3 :darkseagreen1 :lightcoral :grey54 :palevioletred4 :darkseagreen2 :tomato :gray55 :maroon1 :orangered :darkseagreen3 :grey55 :maroon2 :hotpink :gray56 :darkseagreen4 :maroon3 :deeppink :grey56 :seagreen1 :maroon4 :lightpink :gray57 :seagreen2 :violetred1 :palevioletred :grey57 :seagreen3 :violetred2 :maroon :gray58 :seagreen4 :violetred3 :mediumvioletred :grey58 :palegreen1 :violetred4 :gray59 :violetred :palegreen2 :magenta1 :grey59 :magenta :palegreen3 :magenta2 :gray60 :violet :palegreen4 :magenta3 :white :grey60 :plum :springgreen1 :magenta4 :gray61 :orchid :springgreen2 :orchid1 :grey61 :mediumorchid :orchid2 :springgreen3 :gray62 :darkorchid :orchid3 :springgreen4 :grey62 :darkviolet :orchid4 :gray63 :green1 :blueviolet :plum1 :grey63 :green2 :mediumpurple :plum2 :gray64 :green3 :thistle :plum3 :grey64 :green4 :snow1 :plum4 :gray65 :chartreuse1 :snow2 :mediumorchid1 :grey65 :chartreuse2 :snow3 :mediumorchid2 :gray66 :chartreuse3 :snow4 :grey66 :mediumorchid3 :chartreuse4 :seashell1 :gray67 :olivedrab1 :mediumorchid4 :seashell2 :olivedrab2 :grey67 :darkorchid1 :seashell3 :olivedrab3 :gray68 :darkorchid2 :seashell4 :olivedrab4 :grey68 :darkorchid3 :antiquewhite1 :darkolivegreen1 :gray69 :darkorchid4 :antiquewhite2 :grey69 :darkolivegreen2 :purple1 :antiquewhite3 :gray70 :purple2 :darkolivegreen3 :antiquewhite4 :grey70 :purple3 :darkolivegreen4 :gray71 :bisque1 :purple4 :khaki1 :grey71 :bisque2 :mediumpurple1 :khaki2 :gray72 :bisque3 :mediumpurple2 :khaki3 :grey72 :bisque4 :mediumpurple3 :khaki4 :gray73 :peachpuff1 :lightgoldenrod1 :mediumpurple4 :grey73 :peachpuff2 :lightgoldenrod2 :gray74 :thistle1 :peachpuff3 :grey74 :thistle2 :lightgoldenrod3 :peachpuff4 :gray75 :thistle3 :navajowhite1 :lightgoldenrod4 :grey75 :thistle4 :navajowhite2 :lightyellow1 :gray76 :gray0 :snow :navajowhite3 :lightyellow2 :grey76 :grey0 :ghostwhite :navajowhite4 :lightyellow3 :gray77 :gray1 :whitesmoke :lemonchiffon1 :grey77 :lightyellow4 :gainsboro :grey1 :gray78 :lemonchiffon2 :floralwhite :gray2 :yellow1 :grey78 :oldlace :grey2 :yellow2 :lemonchiffon3 :blue :gray79 :linen :gray3 :yellow3 :lemonchiffon4 :yellow :grey79 :antiquewhite :grey3 :yellow4 :cornsilk1 :purple :gray80 :gray4 :gold1 :papayawhip :cornsilk2 :cyan :grey80 :grey4 :gold2 :blanchedalmond :cornsilk3 :green :gray81 :gray5 :gold3 :bisque :cornsilk4 :lightyellow :grey81 :grey5 :gold4 :peachpuff :ivory1 :grey :gray82 :gray6 :goldenrod1 :navajowhite :ivory2 :lightgrey :grey82 :grey6 :goldenrod2 :moccasin :ivory3 :gray83 :gray7 :goldenrod3 :cornsilk :ivory4 :grey83 :grey7 :goldenrod4 :ivory :honeydew1 :gray84 :gray8 :darkgoldenrod1 :lemonchiffon :honeydew2 :grey84 :grey8 :darkgoldenrod2 :honeydew3 :seashell :gray85 :gray9 :darkgoldenrod3 :honeydew4 :honeydew :grey85 :grey9 :lavenderblush1 :mintcream :darkgoldenrod4 :gray86 :gray10)
